@@ -117,10 +117,13 @@ get_eurostat <- function(id, time_format = "date", filters = "none",
                          stringsAsFactors = default.stringsAsFactors(),
                          keepFlags = FALSE, ...){
   
-  # Check if you have internet connection
-  internet_available <- curl::has_internet()
-  if (!internet_available) stop("You have no internet connection, please reconnect!")
-			 
+  # Check if you have access to ec.europe.eu. 
+  if (!check_access_to_data()){
+    message("You have no access to ec.europe.eu. 
+Please check your connection and/or review your proxy settings")
+  } else {
+  
+
   #Warning for flags with filter
   if (keepFlags & !is.character(filters) && filters != "none") {
     warning("The keepFlags argument of the get_eurostat function can be used only without filters. 
@@ -209,5 +212,5 @@ get_eurostat <- function(id, time_format = "date", filters = "none",
   }
 
   y
-
+}
 }
