@@ -32,14 +32,17 @@
 #' @keywords utilities database
 search_eurostat <- function(pattern, type = "dataset", fixed = TRUE) {
   
-  # Check if you have internet connection
-  internet_available <- curl::has_internet()
-  if (!internet_available) stop("You have no internet connection, please reconnect!")
+  # Check if you have access to ec.europe.eu. 
+  if (!check_access_to_data()){
+    message("You have no access to ec.europe.eu. 
+Please check your connection and/or review your proxy settings")
+  } else {
   
   set_eurostat_toc()
   tmp <- get(".eurostatTOC", envir = .EurostatEnv)
   if (type != "all") tmp <- tmp[ tmp$type %in% type, ]
   tmp[ grep(tmp$title, pattern = pattern, fixed = fixed), ]
+  }
 }
 
 
